@@ -6,7 +6,7 @@ uniprotfun =  function (y)
     check12 = which(as.character(HGNC2UniprotID[, 1]) == check11a[1])
     check13 = as.character(HGNC2UniprotID[check12, 2])
     for (i in 1:length(check13)) {
-        temp = getURL(paste("https://www.uniprot.org/uniprot/", 
+        temp = getURL(paste("http://www.uniprot.org/uniprot/", 
             check13[i], ".txt", sep = ""))
         res1 = temp
         write(res1, file = paste(y, ".txt", sep = ""))
